@@ -8,7 +8,7 @@ class DiffBuilder:
     def build(self, resource, payload):
         changes = {k: v for k, v in {**resource, **payload}.items()
                    if k in payload and (k not in resource or resource[k] != payload[k])}
-        return {'old_resource': resource, 'changes': changes} if changes else None
+        return {'changes': changes} if changes else None
 
 
 class OldAndNewBuilder:
@@ -26,7 +26,7 @@ class JsonPatchBuilder:
 
     def build(self, resource, payload):
         patch = list(jsonpatch.make_patch(resource, payload))
-        return {'old_resource': resource, 'patch': patch} if patch else None
+        return {'patch': patch} if patch else None
 
 
 MODE_BUILDERS = {
